﻿using System.Text;
using System.IO.Ports;

using SecretLabs.NETMF.Hardware.NetduinoPlus;
using Microtoolskit.Hardware.Displays;

namespace NetduinoXBEE_R
{
    public class Program
    {
        public static void Main()
        {// Documentation de la classe SerialPort http://msdn.microsoft.com/en-us/library/system.io.ports.serialport(v=vs.102).aspx
            // Récepteur (Message = chaîne de caractères représentant une valeur comprise entre 0 et 65535 suivi de \n)
            // Création d'un port série pour la communication avec le module XBEE installé sur le shield Sparkfun. XBEE_RX sur Di0 et XBEE_TX sur Di1.
            SerialPort xbee_R = new SerialPort(SerialPorts.COM1, 9600, Parity.None, 8, StopBits.One);

            // Pour accéder au COM2, relier l'afficheur au connecteur KK O5 de la carte Tinkerkit
            // Création d'un objet afficheur série ELCD162 (par défaut: COM2, 19200, None, 8, 1)
            ELCD162 display = new ELCD162();

            // Création du buffer de réception           
            byte[] inBuffer = new byte[6] { 0, 0, 0, 0, 0, 0 }; 

            // Initialisation du LCD
            display.Init(); display.ClearScreen(); display.CursorOff();
            int pos = 0; // position dans inBuffer
            xbee_R.Open(); // Ouverture du port série COM1

            while (true)
            {
                bool Aff = false;
       
               // Copie du message reçu dans inBuffer
               do 
                {                   
                    xbee_R.Read(inBuffer, pos, 1);
                    if (inBuffer[pos]!=0x0a)
                    {
                       pos++; // Avance la position dans inBuffer
                    }        // si le caractère fin de ligne '\n' n'est pas atteint
                   else
	                {
                        pos = 0; // Réinitialise la position dans inBuffer
                        Aff = true; // Autorise l'affichage de la donnée
	                }
                                
                } while (xbee_R.BytesToRead > 0);

               // Affichage de la valeur sur le LCD
               if (Aff)
               {
                   char[] chars = Encoding.UTF8.GetChars(inBuffer);
                   int i = MessageSize(inBuffer);
                   string str = new string(chars, 0, i);
                   display.ClearScreen(); display.PutString(str);
                   Clear_Buffer(inBuffer);
               }
            }
        }

        private static int MessageSize(byte[] inBuffer)
        {
            int i;
            for (i = 0; i < inBuffer.Length; i++)
            {
                if ((inBuffer[i] < 0x30) || (inBuffer[i] > 0x39))
                {
                    break;
                }
            }
            return i;
        }

        private static void Clear_Buffer(byte[] inBuffer)
        {
            for (int j = 0; j < inBuffer.Length; j++)
            {
                inBuffer[j] = 0;
            }
        }
    }
}
